# Codice di Condotta del Contributor Covenant

## Il Nostro Impegno

Noi, in quanto membri, contributori e leader, ci impegniamo a rendere la partecipazione nella nostra
comunità un'esperienza libera da molestie per tutti, indipendentemente dall'età, dalle dimensioni del corpo,
dalla disabilità visibile o invisibile, dall'etnia, dalle caratteristiche sessuali, dall'identità e dall'espressione di genere,
dal livello di esperienza, dall'istruzione, dallo status socio-economico, dalla nazionalità, dall'aspetto personale, dalla razza, dalla religione o dall'identità sessuale
e dall'orientamento.

Ci impegniamo ad agire e interagire in modi che contribuiscono a una comunità aperta, accogliente,
diversificata, inclusiva e sana.

## I Nostri Standard

Esempi di comportamento che contribuiscono a un ambiente positivo per la nostra
comunità includono:

* Dimostrare empatia e gentilezza verso gli altri
* Essere rispettosi delle opinioni, dei punti di vista e delle esperienze diverse
* Dare e accettare con grazia feedback costruttivi
* Accettare la responsabilità e scusarsi con coloro che sono stati colpiti dai nostri errori,
  e imparare dall'esperienza
* Concentrarsi su ciò che è meglio non solo per noi come individui, ma per l'intera
  comunità

Esempi di comportamenti inaccettabili includono:

* L'uso di linguaggio o immagini sessualizzati, e attenzioni o avance sessuali di qualsiasi tipo
* Trollaggio, commenti insultanti o denigratori, e attacchi personali o politici
* Molestie pubbliche o private
* Pubblicare informazioni private altrui, come un indirizzo fisico o email, senza il loro esplicito consenso
* Altri comportamenti che potrebbero ragionevolmente essere considerati inappropriati in un contesto professionale

## Responsabilità di Applicazione

I leader della comunità sono responsabili di chiarire e far rispettare i nostri standard di
comportamento accettabile e intraprenderanno azioni correttive appropriate ed eque in
risposta a qualsiasi comportamento che ritengano inappropriato, minaccioso, offensivo,
o dannoso.

I leader della comunità hanno il diritto e la responsabilità di rimuovere, modificare o rifiutare
commenti, commit, codice, modifiche al wiki, issue e altri contributi che non sono
allineati a questo Codice di Condotta, e comunicheranno le ragioni delle decisioni
di moderazione quando appropriato.

## Ambito

Questo Codice di Condotta si applica all'interno di tutti gli spazi della comunità, e si applica anche quando
un individuo rappresenta ufficialmente la comunità in spazi pubblici.
Esempi di rappresentanza della nostra comunità includono l'uso di un indirizzo e-mail ufficiale,
la pubblicazione tramite un account ufficiale sui social media, o l'agire come rappresentante nominato
a un evento online o offline.

## Enforcement

I casi di comportamento abusivo, molesto o altrimenti inaccettabile possono essere
segnalati ai leader della comunità responsabili dell'applicazione all'indirizzo
aw@funstory.ai .
Tutte le segnalazioni saranno esaminate e investigate in modo tempestivo ed equo.

Tutti i leader della comunità sono tenuti a rispettare la privacy e la sicurezza del
segnalante di qualsiasi incidente.

## Linee guida per l'applicazione

I leader della comunità seguiranno queste Linee guida per l'impatto sulla comunità nel determinare
le conseguenze per qualsiasi azione che ritengano in violazione di questo Codice di Condotta:

### 1. Correzione

**Impatto sulla Comunità**: Uso di linguaggio inappropriato o altri comportamenti considerati
non professionali o non graditi nella comunità.

**Conseguenza**: Un avviso scritto privato da parte dei leader della comunità, che fornisce
chiarezza sulla natura della violazione e una spiegazione del perché il
comportamento era inappropriato. Potrebbe essere richiesta una scusa pubblica.

### 2. Avviso

**Impatto sulla Comunità**: Una violazione attraverso un singolo incidente o una serie di azioni.

**Conseguenza**: Un avviso con conseguenze per il comportamento continuato. Nessuna interazione con le persone coinvolte, comprese interazioni non richieste con coloro che applicano il Codice di Condotta, per un periodo di tempo specificato. Ciò include l'evitare interazioni negli spazi della comunità così come nei canali esterni come i social media. La violazione di questi termini può portare a una sospensione temporanea o a un ban permanente.

### 3. Sospensione temporanea

**Impatto sulla Comunità**: Una grave violazione degli standard della comunità, inclusi comportamenti inappropriati persistenti.

**Conseguenza**: Una sospensione temporanea da qualsiasi tipo di interazione o comunicazione pubblica con la comunità per un periodo di tempo specificato. Durante questo periodo, non è consentito alcun intervento pubblico o privato con le persone coinvolte, inclusi interventi non richiesti con coloro che applicano il Codice di Condotta. La violazione di questi termini può portare a un ban permanente.

### 4. Ban permanente

**Impatto sulla Comunità**: Dimostrare un modello di violazione degli standard della comunità, inclusi comportamenti inappropriati prolungati, molestie nei confronti di un individuo, o aggressività o denigrazione verso classi di individui.

**Conseguenza**: Un ban permanente da qualsiasi tipo di interazione pubblica all'interno della comunità.

## Attribuzione

Questo Codice di Condotta è adattato dal [Contributor Covenant][homepage],
versione 2.0, disponibile all'indirizzo
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Le Linee guida sull'impatto della comunità sono state ispirate dal [codice di condotta
e scala di enforcement di Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Per risposte alle domande frequenti su questo codice di condotta, consulta le Domande frequenti all'indirizzo
https://www.contributor-covenant.org/faq. Le traduzioni sono disponibili all'indirizzo
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>